@@ -25,6 +25,8 @@ def underscore_func_node_names_maker(func: Callable, name=None, out=None):
     that argument has the the function's (output) name.
     """
     if name is not None and out is not None:
+        if name == out:
+            name = name + '_'
         return name, out
 
     try:
@@ -41,6 +43,8 @@ def underscore_func_node_names_maker(func: Callable, name=None, out=None):
     elif out is None:
         return name, '_' + name
     elif name is None:
+        if name_of_func == out:
+            name_of_func += '_'
         return name_of_func, out
 
 
