@@ -133,7 +133,7 @@ class Operation:
         """
         Display more informative names for the Operation class
         """
-        return u"%s(name='%s', needs=%s, provides=%s)" % (
+        return "%s(name='%s', needs=%s, provides=%s)" % (
             self.__class__.__name__,
             self.name,
             self.needs,
@@ -869,7 +869,7 @@ with suppress(ModuleNotFoundError, ImportError):
             """
             Display more informative names for the Operation class
             """
-            return u"%s(name='%s', needs=%s, provides=%s, fn=%s)" % (
+            return "%s(name='%s', needs=%s, provides=%s, fn=%s)" % (
                 self.__class__.__name__,
                 self.name,
                 self.needs,
